@@ -6,7 +6,6 @@
 
 // spell-checker:ignore (ToDO) adFfmprt, kmerge
 
-use chrono::{DateTime, Local};
 use clap::{Arg, ArgAction, ArgMatches, Command};
 use itertools::Itertools;
 use regex::Regex;
@@ -14,15 +13,15 @@ use std::fs::{File, metadata};
 use std::io::{BufRead, BufReader, Lines, Read, Write, stdin, stdout};
 #[cfg(unix)]
 use std::os::unix::fs::FileTypeExt;
+use std::time::SystemTime;
 use thiserror::Error;
 
 use uucore::display::Quotable;
 use uucore::error::UResult;
-use uucore::{format_usage, help_about, help_section, help_usage};
+use uucore::format_usage;
+use uucore::time::{FormatSystemTimeFallback, format, format_system_time};
+use uucore::translate;
 
-const ABOUT: &str = help_about!("pr.md");
-const USAGE: &str = help_usage!("pr.md");
-const AFTER_HELP: &str = help_section!("after help", "pr.md");
 const TAB: char = '\t';
 const LINES_PER_PAGE: usize = 66;
 const LINES_PER_PAGE_FOR_FORM_FEED: usize = 63;
@@ -34,10 +33,10 @@ const DEFAULT_COLUMN_WIDTH: usize = 72;
 const DEFAULT_COLUMN_WIDTH_WITH_S_OPTION: usize = 512;
 const DEFAULT_COLUMN_SEPARATOR: &char = &TAB;
 const FF: u8 = 0x0C_u8;
-const DATE_TIME_FORMAT: &str = "%b %d %H:%M %Y";
 
 mod options {
     pub const HEADER: &str = "header";
+    pub const DATE_FORMAT: &str = "date-format";
     pub const DOUBLE_SPACE: &str = "double-space";
     pub const NUMBER_LINES: &str = "number-lines";
     pub const FIRST_LINE_NUMBER: &str = "first-line-number";
@@ -129,74 +128,75 @@ impl Default for FileLine {
 
 impl From<std::io::Error> for PrError {
     fn from(err: std::io::Error) -> Self {
-        Self::EncounteredErrors(err.to_string())
+        Self::EncounteredErrors {
+            msg: err.to_string(),
+        }
     }
 }
 
 #[derive(Debug, Error)]
 enum PrError {
-    #[error("pr: Reading from input {1} gave error")]
-    Input(std::io::Error, String),
-    #[error("pr: {0}: unknown filetype")]
-    UnknownFiletype(String),
-    #[error("pr: {0}")]
-    EncounteredErrors(String),
-    #[error("pr: {0}: Is a directory")]
-    IsDirectory(String),
+    #[error("{}", translate!("pr-error-reading-input", "file" => file.clone()))]
+    Input {
+        #[source]
+        source: std::io::Error,
+        file: String,
+    },
+    #[error("{}", translate!("pr-error-unknown-filetype", "file" => file.clone()))]
+    UnknownFiletype { file: String },
+    #[error("pr: {msg}")]
+    EncounteredErrors { msg: String },
+    #[error("{}", translate!("pr-error-is-directory", "file" => file.clone()))]
+    IsDirectory { file: String },
     #[cfg(not(windows))]
-    #[error("pr: cannot open {0}, Operation not supported on socket")]
-    IsSocket(String),
-    #[error("pr: cannot open {0}, No such file or directory")]
-    NotExists(String),
+    #[error("{}", translate!("pr-error-socket-not-supported", "file" => file.clone()))]
+    IsSocket { file: String },
+    #[error("{}", translate!("pr-error-no-such-file", "file" => file.clone()))]
+    NotExists { file: String },
 }
 
 pub fn uu_app() -> Command {
     Command::new(uucore::util_name())
         .version(uucore::crate_version!())
-        .about(ABOUT)
-        .after_help(AFTER_HELP)
-        .override_usage(format_usage(USAGE))
+        .help_template(uucore::localized_help_template(uucore::util_name()))
+        .about(translate!("pr-about"))
+        .after_help(translate!("pr-after-help"))
+        .override_usage(format_usage(&translate!("pr-usage")))
         .infer_long_args(true)
         .args_override_self(true)
         .disable_help_flag(true)
         .arg(
             Arg::new(options::PAGES)
                 .long(options::PAGES)
-                .help("Begin and stop printing with page FIRST_PAGE[:LAST_PAGE]")
+                .help(translate!("pr-help-pages"))
                 .value_name("FIRST_PAGE[:LAST_PAGE]"),
         )
         .arg(
             Arg::new(options::HEADER)
                 .short('h')
                 .long(options::HEADER)
-                .help(
-                    "Use the string header to replace the file name \
-                    in the header line.",
-                )
+                .help(translate!("pr-help-header"))
                 .value_name("STRING"),
         )
+        .arg(
+            Arg::new(options::DATE_FORMAT)
+                .short('D')
+                .long(options::DATE_FORMAT)
+                .value_name("FORMAT")
+                .help(translate!("pr-help-date-format")),
+        )
         .arg(
             Arg::new(options::DOUBLE_SPACE)
                 .short('d')
                 .long(options::DOUBLE_SPACE)
-                .help(
-                    "Produce output that is double spaced. An extra <newline> \
-                character is output following every <newline> found in the input.",
-                )
+                .help(translate!("pr-help-double-space"))
                 .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(options::NUMBER_LINES)
                 .short('n')
                 .long(options::NUMBER_LINES)
-                .help(
-                    "Provide width digit line numbering.  The default for width, \
-                if not specified, is 5.  The number occupies the first width column \
-                positions of each text column or each line of -m output.  If char \
-                (any non-digit character) is given, it is appended to the line number \
-                to separate it from whatever follows.  The default for char is a <tab>. \
-                Line numbers longer than width columns are truncated.",
-                )
+                .help(translate!("pr-help-number-lines"))
                 .allow_hyphen_values(true)
                 .value_name("[char][width]"),
         )
@@ -204,38 +204,28 @@ pub fn uu_app() -> Command {
             Arg::new(options::FIRST_LINE_NUMBER)
                 .short('N')
                 .long(options::FIRST_LINE_NUMBER)
-                .help("start counting with NUMBER at 1st line of first page printed")
+                .help(translate!("pr-help-first-line-number"))
                 .value_name("NUMBER"),
         )
         .arg(
             Arg::new(options::OMIT_HEADER)
                 .short('t')
                 .long(options::OMIT_HEADER)
-                .help(
-                    "Write neither the five-line identifying header nor the five-line \
-                trailer usually supplied for each page. Quit writing after the last line \
-                 of each file without spacing to the end of the page.",
-                )
+                .help(translate!("pr-help-omit-header"))
                 .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(options::PAGE_LENGTH)
                 .short('l')
                 .long(options::PAGE_LENGTH)
-                .help(
-                    "Override the 66-line default (default number of lines of text 56, \
-                    and with -F 63) and reset the page length to lines.  If lines is not \
-                    greater than the sum  of  both the  header  and trailer depths (in lines), \
-                    the pr utility shall suppress both the header and trailer, as if the -t \
-                    option were in effect. ",
-                )
+                .help(translate!("pr-help-page-length"))
                 .value_name("PAGE_LENGTH"),
         )
         .arg(
             Arg::new(options::NO_FILE_WARNINGS)
                 .short('r')
                 .long(options::NO_FILE_WARNINGS)
-                .help("omit warning when a file cannot be opened")
+                .help(translate!("pr-help-no-file-warnings"))
                 .action(ArgAction::SetTrue),
         )
         .arg(
@@ -243,118 +233,74 @@ pub fn uu_app() -> Command {
                 .short('F')
                 .short_alias('f')
                 .long(options::FORM_FEED)
-                .help(
-                    "Use a <form-feed> for new pages, instead of the default behavior that \
-                uses a sequence of <newline>s.",
-                )
+                .help(translate!("pr-help-form-feed"))
                 .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(options::COLUMN_WIDTH)
                 .short('w')
                 .long(options::COLUMN_WIDTH)
-                .help(
-                    "Set the width of the line to width column positions for multiple \
-                text-column output only. If the -w option is not specified and the -s option \
-                is not specified, the default width shall be 72. If the -w option is not specified \
-                and the -s option is specified, the default width shall be 512.",
-                )
+                .help(translate!("pr-help-column-width"))
                 .value_name("width"),
         )
         .arg(
             Arg::new(options::PAGE_WIDTH)
                 .short('W')
                 .long(options::PAGE_WIDTH)
-                .help(
-                    "set page width to PAGE_WIDTH (72) characters always, \
-                truncate lines, except -J option is set, no interference \
-                with -S or -s",
-                )
+                .help(translate!("pr-help-page-width"))
                 .value_name("width"),
         )
         .arg(
             Arg::new(options::ACROSS)
                 .short('a')
                 .long(options::ACROSS)
-                .help(
-                    "Modify the effect of the - column option so that the columns are filled \
-                across the page in a  round-robin  order (for example, when column is 2, the \
-                first input line heads column 1, the second heads column 2, the third is the \
-                second line in column 1, and so on).",
-                )
+                .help(translate!("pr-help-across"))
                 .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(options::COLUMN)
                 .long(options::COLUMN)
-                .help(
-                    "Produce multi-column output that is arranged in column columns \
-                (the default shall be 1) and is written down each column  in  the order in which \
-                the text is received from the input file. This option should not be used with -m. \
-                The options -e and -i shall be assumed for multiple text-column output.  Whether \
-                or not text columns are produced with identical vertical lengths is unspecified, \
-                but a text column shall never exceed the length of the page (see the -l option). \
-                When used with -t, use the minimum number of lines to write the output.",
-                )
+                .help(translate!("pr-help-column"))
                 .value_name("column"),
         )
         .arg(
             Arg::new(options::COLUMN_CHAR_SEPARATOR)
                 .short('s')
                 .long(options::COLUMN_CHAR_SEPARATOR)
-                .help(
-                    "Separate text columns by the single character char instead of by the \
-                appropriate number of <space>s (default for char is the <tab> character).",
-                )
+                .help(translate!("pr-help-column-char-separator"))
                 .value_name("char"),
         )
         .arg(
             Arg::new(options::COLUMN_STRING_SEPARATOR)
                 .short('S')
                 .long(options::COLUMN_STRING_SEPARATOR)
-                .help(
-                    "separate columns by STRING, \
-                without -S: Default separator <TAB> with -J and <space> \
-                otherwise (same as -S\" \"), no effect on column options",
-                )
+                .help(translate!("pr-help-column-string-separator"))
                 .value_name("string"),
         )
         .arg(
             Arg::new(options::MERGE)
                 .short('m')
                 .long(options::MERGE)
-                .help(
-                    "Merge files. Standard output shall be formatted so the pr utility \
-                writes one line from each file specified by a file operand, side by side \
-                into text columns of equal fixed widths, in terms of the number of column \
-                positions. Implementations shall support merging of at least nine file operands.",
-                )
+                .help(translate!("pr-help-merge"))
                 .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(options::INDENT)
                 .short('o')
                 .long(options::INDENT)
-                .help(
-                    "Each line of output shall be preceded by offset <space>s. If the -o \
-                option is not specified, the default offset shall be zero. The space taken is \
-                in addition to the output line width (see the -w option below).",
-                )
+                .help(translate!("pr-help-indent"))
                 .value_name("margin"),
         )
         .arg(
             Arg::new(options::JOIN_LINES)
                 .short('J')
-                .help(
-                    "merge full lines, turns off -W line truncation, no column \
-                alignment, --sep-string[=STRING] sets separators",
-                )
+                .help(translate!("pr-help-join-lines"))
                 .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(options::HELP)
                 .long(options::HELP)
-                .help("Print help information")
+                .help(translate!("pr-help-help"))
                 .action(ArgAction::Help),
         )
         .arg(
@@ -370,8 +316,8 @@ pub fn uumain(args: impl uucore::Args) -> UResult<()> {
 
     let opt_args = recreate_arguments(&args);
 
-    let mut command = uu_app();
-    let matches = command.try_get_matches_from_mut(opt_args)?;
+    let command = uu_app();
+    let matches = uucore::clap_localization::handle_clap_result(command, opt_args)?;
 
     let mut files = matches
         .get_many::<String>(options::FILES)
@@ -454,8 +400,8 @@ fn parse_usize(matches: &ArgMatches, opt: &str) -> Option<Result<usize, PrError>
     let from_parse_error_to_pr_error = |value_to_parse: (String, String)| {
         let i = value_to_parse.0;
         let option = value_to_parse.1;
-        i.parse().map_err(|_e| {
-            PrError::EncounteredErrors(format!("invalid {option} argument {}", i.quote()))
+        i.parse().map_err(|_e| PrError::EncounteredErrors {
+            msg: format!("invalid {option} argument {}", i.quote()),
         })
     };
     matches
@@ -464,6 +410,25 @@ fn parse_usize(matches: &ArgMatches, opt: &str) -> Option<Result<usize, PrError>
         .map(from_parse_error_to_pr_error)
 }
 
+fn get_date_format(matches: &ArgMatches) -> String {
+    match matches.get_one::<String>(options::DATE_FORMAT) {
+        Some(format) => format,
+        None => {
+            // Replicate behavior from GNU manual.
+            if std::env::var("POSIXLY_CORRECT").is_ok()
+                // TODO: This needs to be moved to uucore and handled by icu?
+                && (std::env::var("LC_TIME").unwrap_or_default() == "POSIX"
+                    || std::env::var("LC_ALL").unwrap_or_default() == "POSIX")
+            {
+                "%b %e %H:%M %Y"
+            } else {
+                format::LONG_ISO
+            }
+        }
+    }
+    .to_string()
+}
+
 #[allow(clippy::cognitive_complexity)]
 fn build_options(
     matches: &ArgMatches,
@@ -475,13 +440,15 @@ fn build_options(
     let is_merge_mode = matches.get_flag(options::MERGE);
 
     if is_merge_mode && matches.contains_id(options::COLUMN) {
-        let err_msg = String::from("cannot specify number of columns when printing in parallel");
-        return Err(PrError::EncounteredErrors(err_msg));
+        return Err(PrError::EncounteredErrors {
+            msg: translate!("pr-error-column-merge-conflict"),
+        });
     }
 
     if is_merge_mode && matches.get_flag(options::ACROSS) {
-        let err_msg = String::from("cannot specify both printing across and printing in parallel");
-        return Err(PrError::EncounteredErrors(err_msg));
+        return Err(PrError::EncounteredErrors {
+            msg: translate!("pr-error-across-merge-conflict"),
+        });
     }
 
     let merge_files_print = if matches.get_flag(options::MERGE) {
@@ -492,12 +459,14 @@ fn build_options(
 
     let header = matches
         .get_one::<String>(options::HEADER)
-        .map(|s| s.as_str())
-        .unwrap_or(if is_merge_mode || paths[0] == FILE_STDIN {
-            ""
-        } else {
-            paths[0]
-        })
+        .map_or(
+            if is_merge_mode || paths[0] == FILE_STDIN {
+                ""
+            } else {
+                paths[0]
+            },
+            |s| s.as_str(),
+        )
         .to_string();
 
     let default_first_number = NumberingMode::default().first_number;
@@ -546,11 +515,26 @@ fn build_options(
 
     let line_separator = "\n".to_string();
 
-    let last_modified_time = if is_merge_mode || paths[0].eq(FILE_STDIN) {
-        let date_time = Local::now();
-        date_time.format(DATE_TIME_FORMAT).to_string()
-    } else {
-        file_last_modified_time(paths.first().unwrap())
+    let last_modified_time = {
+        let time = if is_merge_mode || paths[0].eq(FILE_STDIN) {
+            Some(SystemTime::now())
+        } else {
+            metadata(paths.first().unwrap())
+                .ok()
+                .and_then(|i| i.modified().ok())
+        };
+        time.and_then(|time| {
+            let mut v = Vec::new();
+            format_system_time(
+                &mut v,
+                time,
+                &get_date_format(matches),
+                FormatSystemTimeFallback::Integer,
+            )
+            .ok()
+            .map(|()| String::from_utf8_lossy(&v).to_string())
+        })
+        .unwrap_or_default()
     };
 
     // +page option is less priority than --pages
@@ -558,9 +542,11 @@ fn build_options(
     let res = page_plus_re.captures(free_args).map(|i| {
         let unparsed_num = i.get(1).unwrap().as_str().trim();
         let x: Vec<_> = unparsed_num.split(':').collect();
-        x[0].to_string().parse::<usize>().map_err(|_e| {
-            PrError::EncounteredErrors(format!("invalid {} argument {}", "+", unparsed_num.quote()))
-        })
+        x[0].to_string()
+            .parse::<usize>()
+            .map_err(|_e| PrError::EncounteredErrors {
+                msg: format!("invalid {} argument {}", "+", unparsed_num.quote()),
+            })
     });
     let start_page_in_plus_option = match res {
         Some(res) => res?,
@@ -573,13 +559,11 @@ fn build_options(
         .filter(|i| i.contains(':'))
         .map(|unparsed_num| {
             let x: Vec<_> = unparsed_num.split(':').collect();
-            x[1].to_string().parse::<usize>().map_err(|_e| {
-                PrError::EncounteredErrors(format!(
-                    "invalid {} argument {}",
-                    "+",
-                    unparsed_num.quote()
-                ))
-            })
+            x[1].to_string()
+                .parse::<usize>()
+                .map_err(|_e| PrError::EncounteredErrors {
+                    msg: format!("invalid {} argument {}", "+", unparsed_num.quote()),
+                })
         });
     let end_page_in_plus_option = match res {
         Some(res) => Some(res?),
@@ -588,11 +572,8 @@ fn build_options(
 
     let invalid_pages_map = |i: String| {
         let unparsed_value = matches.get_one::<String>(options::PAGES).unwrap();
-        i.parse::<usize>().map_err(|_e| {
-            PrError::EncounteredErrors(format!(
-                "invalid --pages argument {}",
-                unparsed_value.quote()
-            ))
+        i.parse::<usize>().map_err(|_e| PrError::EncounteredErrors {
+            msg: format!("invalid --pages argument {}", unparsed_value.quote()),
         })
     };
 
@@ -623,9 +604,9 @@ fn build_options(
 
     if let Some(end_page) = end_page {
         if start_page > end_page {
-            return Err(PrError::EncounteredErrors(format!(
-                "invalid --pages argument '{start_page}:{end_page}'"
-            )));
+            return Err(PrError::EncounteredErrors {
+                msg: translate!("pr-error-invalid-pages-range", "start" => start_page, "end" => end_page),
+            });
         }
     }
 
@@ -661,8 +642,7 @@ fn build_options(
         Some(x) => Some(x),
         None => matches.get_one::<String>(options::COLUMN_CHAR_SEPARATOR),
     }
-    .map(ToString::to_string)
-    .unwrap_or_else(|| DEFAULT_COLUMN_SEPARATOR.to_string());
+    .map_or_else(|| DEFAULT_COLUMN_SEPARATOR.to_string(), ToString::to_string);
 
     let default_column_width = if matches.contains_id(options::COLUMN_WIDTH)
         && matches.contains_id(options::COLUMN_CHAR_SEPARATOR)
@@ -688,9 +668,11 @@ fn build_options(
 
     let res = re_col.captures(free_args).map(|i| {
         let unparsed_num = i.get(1).unwrap().as_str().trim();
-        unparsed_num.parse::<usize>().map_err(|_e| {
-            PrError::EncounteredErrors(format!("invalid {} argument {}", "-", unparsed_num.quote()))
-        })
+        unparsed_num
+            .parse::<usize>()
+            .map_err(|_e| PrError::EncounteredErrors {
+                msg: format!("invalid {} argument {}", "-", unparsed_num.quote()),
+            })
     });
     let start_column_option = match res {
         Some(res) => Some(res?),
@@ -714,17 +696,17 @@ fn build_options(
     let offset_spaces = " ".repeat(parse_usize(matches, options::INDENT).unwrap_or(Ok(0))?);
     let join_lines = matches.get_flag(options::JOIN_LINES);
 
-    let col_sep_for_printing = column_mode_options
-        .as_ref()
-        .map(|i| i.column_separator.clone())
-        .unwrap_or_else(|| {
+    let col_sep_for_printing = column_mode_options.as_ref().map_or_else(
+        || {
             merge_files_print
                 .map(|_k| DEFAULT_COLUMN_SEPARATOR.to_string())
                 .unwrap_or_default()
-        });
+        },
+        |i| i.column_separator.clone(),
+    );
 
-    let columns_to_print = merge_files_print
-        .unwrap_or_else(|| column_mode_options.as_ref().map(|i| i.columns).unwrap_or(1));
+    let columns_to_print =
+        merge_files_print.unwrap_or_else(|| column_mode_options.as_ref().map_or(1, |i| i.columns));
 
     let line_width = if join_lines {
         None
@@ -732,8 +714,7 @@ fn build_options(
         Some(
             column_mode_options
                 .as_ref()
-                .map(|i| i.width)
-                .unwrap_or(DEFAULT_COLUMN_WIDTH),
+                .map_or(DEFAULT_COLUMN_WIDTH, |i| i.width),
         )
     } else {
         page_width
@@ -767,31 +748,45 @@ fn open(path: &str) -> Result<Box<dyn Read>, PrError> {
         return Ok(Box::new(stdin) as Box<dyn Read>);
     }
 
-    metadata(path)
-        .map(|i| {
+    metadata(path).map_or_else(
+        |_| {
+            Err(PrError::NotExists {
+                file: path.to_string(),
+            })
+        },
+        |i| {
             let path_string = path.to_string();
             match i.file_type() {
                 #[cfg(unix)]
-                ft if ft.is_block_device() => Err(PrError::UnknownFiletype(path_string)),
+                ft if ft.is_block_device() => Err(PrError::UnknownFiletype { file: path_string }),
                 #[cfg(unix)]
-                ft if ft.is_char_device() => Err(PrError::UnknownFiletype(path_string)),
+                ft if ft.is_char_device() => Err(PrError::UnknownFiletype { file: path_string }),
                 #[cfg(unix)]
-                ft if ft.is_fifo() => Err(PrError::UnknownFiletype(path_string)),
+                ft if ft.is_fifo() => Err(PrError::UnknownFiletype { file: path_string }),
                 #[cfg(unix)]
-                ft if ft.is_socket() => Err(PrError::IsSocket(path_string)),
-                ft if ft.is_dir() => Err(PrError::IsDirectory(path_string)),
-                ft if ft.is_file() || ft.is_symlink() => Ok(Box::new(
-                    File::open(path).map_err(|e| PrError::Input(e, path.to_string()))?,
-                ) as Box<dyn Read>),
-                _ => Err(PrError::UnknownFiletype(path_string)),
+                ft if ft.is_socket() => Err(PrError::IsSocket { file: path_string }),
+                ft if ft.is_dir() => Err(PrError::IsDirectory { file: path_string }),
+                ft if ft.is_file() || ft.is_symlink() => {
+                    Ok(Box::new(File::open(path).map_err(|e| PrError::Input {
+                        source: e,
+                        file: path.to_string(),
+                    })?) as Box<dyn Read>)
+                }
+                _ => Err(PrError::UnknownFiletype { file: path_string }),
             }
-        })
-        .unwrap_or_else(|_| Err(PrError::NotExists(path.to_string())))
+        },
+    )
 }
 
 fn split_lines_if_form_feed(file_content: Result<String, std::io::Error>) -> Vec<FileLine> {
-    file_content
-        .map(|content| {
+    file_content.map_or_else(
+        |e| {
+            vec![FileLine {
+                line_content: Err(e),
+                ..FileLine::default()
+            }]
+        },
+        |content| {
             let mut lines = Vec::new();
             let mut f_occurred = 0;
             let mut chunk = Vec::new();
@@ -820,13 +815,8 @@ fn split_lines_if_form_feed(file_content: Result<String, std::io::Error>) -> Vec
             });
 
             lines
-        })
-        .unwrap_or_else(|e| {
-            vec![FileLine {
-                line_content: Err(e),
-                ..FileLine::default()
-            }]
-        })
+        },
+    )
 }
 
 fn pr(path: &str, options: &OutputOptions) -> Result<i32, PrError> {
@@ -1023,8 +1013,7 @@ fn write_columns(
     let across_mode = options
         .column_mode_options
         .as_ref()
-        .map(|i| i.across_mode)
-        .unwrap_or(false);
+        .is_some_and(|i| i.across_mode);
 
     let mut filled_lines = Vec::new();
     if options.merge_files_print.is_some() {
@@ -1088,9 +1077,8 @@ fn write_columns(
         }
         if not_found_break && feed_line_present {
             break;
-        } else {
-            out.write_all(line_separator)?;
         }
+        out.write_all(line_separator)?;
     }
 
     Ok(lines_printed)
@@ -1164,8 +1152,10 @@ fn get_formatted_line_number(opts: &OutputOptions, line_number: usize, index: us
 fn header_content(options: &OutputOptions, page: usize) -> Vec<String> {
     if options.display_header_and_trailer {
         let first_line = format!(
-            "{} {} Page {page}",
-            options.last_modified_time, options.header
+            "{} {} {} {page}",
+            options.last_modified_time,
+            options.header,
+            translate!("pr-page")
         );
         vec![
             String::new(),
@@ -1179,19 +1169,6 @@ fn header_content(options: &OutputOptions, page: usize) -> Vec<String> {
     }
 }
 
-fn file_last_modified_time(path: &str) -> String {
-    metadata(path)
-        .map(|i| {
-            i.modified()
-                .map(|x| {
-                    let date_time: DateTime<Local> = x.into();
-                    date_time.format(DATE_TIME_FORMAT).to_string()
-                })
-                .unwrap_or_default()
-        })
-        .unwrap_or_default()
-}
-
 /// Returns five empty lines as trailer content if displaying trailer
 /// is not disabled by using `NO_HEADER_TRAILER_OPTION`option.
 fn trailer_content(options: &OutputOptions) -> Vec<String> {
@@ -1212,7 +1189,7 @@ fn trailer_content(options: &OutputOptions) -> Vec<String> {
 /// If -N is specified the first line number changes otherwise
 /// default is 1.
 fn get_start_line_number(opts: &OutputOptions) -> usize {
-    opts.number.as_ref().map(|i| i.first_number).unwrap_or(1)
+    opts.number.as_ref().map_or(1, |i| i.first_number)
 }
 
 /// Returns number of lines to read from input for constructing one page of pr output.
@@ -1230,8 +1207,5 @@ fn lines_to_read_for_page(opts: &OutputOptions) -> usize {
 
 /// Returns number of columns to output
 fn get_columns(opts: &OutputOptions) -> usize {
-    opts.column_mode_options
-        .as_ref()
-        .map(|i| i.columns)
-        .unwrap_or(1)
+    opts.column_mode_options.as_ref().map_or(1, |i| i.columns)
 }
